@@ -776,6 +776,7 @@ download_started_cb (WebKitWebContext *web_context,
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
   g_autoptr (EphyDownload) ephy_download = NULL;
   gboolean ephy_download_set;
+  WebKitWebView *web_view;
 
   /* Is download locked down? */
   if (g_settings_get_boolean (EPHY_SETTINGS_LOCKDOWN,
@@ -794,7 +795,19 @@ download_started_cb (WebKitWebContext *web_context,
     return;
 
   ephy_download = ephy_download_new (download);
-  ephy_downloads_manager_add_download (priv->downloads_manager, ephy_download);
+
+  web_view = webkit_download_get_web_view (download);
+  if (EPHY_IS_WEB_VIEW (web_view)) {
+    EphyEmbed *embed;
+
+    embed = EPHY_GET_EMBED_FROM_EPHY_WEB_VIEW (web_view);
+    ephy_embed_download_started (embed, ephy_download);
+
+    if (!ephy_web_view_in_pdf_viewer (EPHY_WEB_VIEW (web_view)))
+      ephy_downloads_manager_add_download (priv->downloads_manager, ephy_download);
+  } else {
+    ephy_downloads_manager_add_download (priv->downloads_manager, ephy_download);
+  }
 }
 
 static void
@@ -828,7 +841,13 @@ ephy_embed_shell_startup (GApplication *application)
 
   webkit_web_context_set_process_model (priv->web_context, WEBKIT_PROCESS_MODEL_MULTIPLE_SECONDARY_PROCESSES);
 
-  webkit_web_context_set_sandbox_enabled (priv->web_context, TRUE);
+  /* Disable sandbox for the moment until:
+   *   - printing: https://bugs.webkit.org/show_bug.cgi?id=202363
+   *   - local browsing: https://bugs.webkit.org/show_bug.cgi?id=202071
+   *   - leaking sockets: https://bugs.webkit.org/show_bug.cgi?id=201771
+   * are fixed.
+   */
+  webkit_web_context_set_sandbox_enabled (priv->web_context, FALSE);
   webkit_web_context_add_path_to_sandbox (priv->web_context, ephy_profile_dir (), TRUE);
   webkit_web_context_add_path_to_sandbox (priv->web_context, ephy_cache_dir (), TRUE);
   webkit_web_context_add_path_to_sandbox (priv->web_context, ephy_config_dir (), TRUE);
