@@ -27,13 +27,13 @@
 #include "ephy-favicon-helpers.h"
 
 struct _EphyBookmarkRow {
-  GtkListBoxRow    parent_instance;
+  GtkListBoxRow parent_instance;
 
-  EphyBookmark    *bookmark;
+  EphyBookmark *bookmark;
 
-  GtkWidget       *favicon_image;
-  GtkWidget       *title_label;
-  GtkWidget       *properties_button;
+  GtkWidget *favicon_image;
+  GtkWidget *title_label;
+  GtkWidget *properties_button;
 };
 
 G_DEFINE_TYPE (EphyBookmarkRow, ephy_bookmark_row, GTK_TYPE_LIST_BOX_ROW)
@@ -61,6 +61,7 @@ ephy_bookmark_row_button_clicked_cb (EphyBookmarkRow *row,
                          "title", _("Bookmark Properties"),
                          "transient-for", GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (row))),
                          "use-header-bar", TRUE,
+                         "resizable", FALSE,
                          "modal", TRUE,
                          NULL);
 
@@ -82,10 +83,10 @@ ephy_bookmark_row_favicon_loaded_cb (GObject      *source,
                                      GAsyncResult *result,
                                      gpointer      user_data)
 {
-  EphyBookmarkRow *self = user_data;
+  g_autoptr (EphyBookmarkRow) self = user_data;
   WebKitFaviconDatabase *database = WEBKIT_FAVICON_DATABASE (source);
   cairo_surface_t *icon_surface;
-  GdkPixbuf *favicon = NULL;
+  g_autoptr (GdkPixbuf) favicon = NULL;
 
   g_assert (EPHY_IS_BOOKMARK_ROW (self));
 
@@ -98,10 +99,7 @@ ephy_bookmark_row_favicon_loaded_cb (GObject      *source,
   if (favicon) {
     if (self->favicon_image != NULL)
       gtk_image_set_from_pixbuf (GTK_IMAGE (self->favicon_image), favicon);
-    g_object_unref (favicon);
   }
-
-  g_object_unref (self);
 }
 
 static void
@@ -112,32 +110,30 @@ ephy_bookmark_row_set_property (GObject      *object,
 {
   EphyBookmarkRow *self = EPHY_BOOKMARK_ROW (object);
 
-  switch (prop_id)
-    {
+  switch (prop_id) {
     case PROP_BOOKMARK:
       self->bookmark = g_value_dup_object (value);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-    }
+  }
 }
 
 static void
-ephy_bookmark_row_get_property (GObject      *object,
-                                guint         prop_id,
-                                GValue       *value,
-                                GParamSpec   *pspec)
+ephy_bookmark_row_get_property (GObject    *object,
+                                guint       prop_id,
+                                GValue     *value,
+                                GParamSpec *pspec)
 {
   EphyBookmarkRow *self = EPHY_BOOKMARK_ROW (object);
 
-  switch (prop_id)
-    {
+  switch (prop_id) {
     case PROP_BOOKMARK:
       g_value_set_object (value, ephy_bookmark_row_get_bookmark (self));
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-    }
+  }
 }
 
 static void
@@ -157,6 +153,31 @@ favicon_image_destroyed (EphyBookmarkRow *self,
   self->favicon_image = NULL;
 }
 
+static gboolean
+transform_bookmark_title (GBinding     *binding,
+                          const GValue *from_value,
+                          GValue       *to_value,
+                          gpointer      user_data)
+{
+  const char *title;
+
+  title = g_value_get_string (from_value);
+
+  if (strlen (title) == 0) {
+    EphyBookmark *bookmark;
+    const char *url;
+
+    bookmark = EPHY_BOOKMARK (user_data);
+    url = ephy_bookmark_get_url (bookmark);
+
+    g_value_set_string (to_value, url);
+  } else {
+    g_value_set_string (to_value, title);
+  }
+
+  return TRUE;
+}
+
 static void
 ephy_bookmark_row_constructed (GObject *object)
 {
@@ -166,9 +187,12 @@ ephy_bookmark_row_constructed (GObject *object)
 
   G_OBJECT_CLASS (ephy_bookmark_row_parent_class)->constructed (object);
 
-  g_object_bind_property (self->bookmark, "title",
-                          self->title_label, "label",
-                          G_BINDING_SYNC_CREATE);
+  g_object_bind_property_full (self->bookmark, "title",
+                               self->title_label, "label",
+                               G_BINDING_SYNC_CREATE,
+                               transform_bookmark_title,
+                               NULL,
+                               self->bookmark, NULL);
 
   database = webkit_web_context_get_favicon_database (ephy_embed_shell_get_web_context (shell));
   webkit_favicon_database_get_favicon (database,
