@@ -32,7 +32,7 @@ G_BEGIN_DECLS
 G_DECLARE_FINAL_TYPE (EphyBookmarksManager, ephy_bookmarks_manager, EPHY, BOOKMARKS_MANAGER, GObject)
 
 #define EPHY_BOOKMARKS_FAVORITES_TAG    _("Favorites")
-#define EPHY_BOOKMARKS_MOBILE_TAG       N_("Mobile")
+#define EPHY_BOOKMARKS_MOBILE_TAG       _("Mobile")
 #define FIREFOX_BOOKMARKS_MOBILE_FOLDER "Mobile Bookmarks"
 
 EphyBookmarksManager *ephy_bookmarks_manager_new                    (void);
