@@ -54,7 +54,6 @@ struct _EphyNotebook {
   EphyAdaptiveMode adaptive_mode;
 
   GList *focused_pages;
-  guint tabs_vis_notifier_id;
 
   GMenu *tab_menu;
 
@@ -505,10 +504,9 @@ get_last_pinned_tab_pos (EphyNotebook *notebook)
 }
 
 static void
-page_reordered_cb (GtkNotebook *notebook,
-                   GtkWidget   *child,
-                   guint        page_num,
-                   gpointer     user_data)
+ephy_notebook_ensure_pinned_tab_position (GtkNotebook *notebook,
+                                          GtkWidget   *child,
+                                          guint        page_num)
 {
   int last_pinned_tab_pos = get_last_pinned_tab_pos (EPHY_NOTEBOOK (notebook));
   gboolean is_current_tab_pinned = ephy_notebook_tab_is_pinned (EPHY_NOTEBOOK (notebook), EPHY_EMBED (child));
@@ -521,6 +519,15 @@ page_reordered_cb (GtkNotebook *notebook,
   }
 }
 
+static void
+page_reordered_cb (GtkNotebook *notebook,
+                   GtkWidget   *child,
+                   guint        page_num,
+                   gpointer     user_data)
+{
+  ephy_notebook_ensure_pinned_tab_position (notebook, child, page_num);
+}
+
 static void
 ephy_notebook_init (EphyNotebook *notebook)
 {
@@ -901,6 +908,8 @@ ephy_notebook_page_added (GtkNotebook *notebook,
   if (GTK_NOTEBOOK_CLASS (ephy_notebook_parent_class)->page_added != NULL)
     GTK_NOTEBOOK_CLASS (ephy_notebook_parent_class)->page_added (notebook, child, page_num);
 
+  ephy_notebook_ensure_pinned_tab_position (notebook, child, page_num);
+
   ephy_notebook_rebuild_tab_menu (EPHY_NOTEBOOK (notebook));
 }
 
@@ -1015,6 +1024,7 @@ ephy_notebook_tab_set_pinned (EphyNotebook *notebook,
   gboolean expanded;
 
   gtk_notebook_set_tab_reorderable (GTK_NOTEBOOK (notebook), embed, !is_pinned);
+  gtk_notebook_set_tab_detachable (GTK_NOTEBOOK (notebook), embed, !is_pinned);
   tab_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (notebook), embed);
   ephy_tab_label_set_pinned (tab_label, is_pinned);
 
