@@ -123,7 +123,7 @@ load_changed_cb (WebKitWebView   *view,
                  WebKitLoadEvent  load_event,
                  EphySession     *session)
 {
-  if (ephy_web_view_get_load_failed (EPHY_WEB_VIEW (view)))
+  if (ephy_web_view_load_failed (EPHY_WEB_VIEW (view)))
     return;
 
   if (load_event == WEBKIT_LOAD_FINISHED)
@@ -1099,6 +1099,8 @@ static void
 session_parser_context_free (SessionParserContext *context)
 {
   g_object_unref (context->session);
+  if (context->window)
+    g_object_unref (context->window);
 
   g_free (context);
 }
@@ -1111,7 +1113,9 @@ session_parse_window (SessionParserContext  *context,
   GdkRectangle geometry = { -1, -1, 0, 0 };
   guint i;
 
+  g_assert (!context->window);
   context->window = ephy_window_new ();
+  g_object_ref (context->window);
 
   for (i = 0; names[i]; i++) {
     gulong int_value;
@@ -1291,6 +1295,7 @@ session_end_element (GMarkupParseContext  *ctx,
 
       active_child = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (context->window));
       gtk_widget_grab_focus (GTK_WIDGET (active_child));
+      ephy_window_update_entry_focus (context->window, ephy_embed_get_web_view (active_child));
       gtk_widget_show (GTK_WIDGET (context->window));
     }
 
@@ -1690,14 +1695,15 @@ ephy_session_resume (EphySession         *session,
 
   shell = ephy_shell_get_default ();
 
+  /* If we are auto-resuming, and we never want to
+   * restore the session, clobber the session state
+   * file.
+   */
+  if (policy == EPHY_PREFS_RESTORE_SESSION_POLICY_NEVER)
+    session_delete (session);
+
   if (has_session_state == FALSE ||
       policy == EPHY_PREFS_RESTORE_SESSION_POLICY_NEVER) {
-    /* If we are auto-resuming, and we never want to
-     * restore the session, clobber the session state
-     * file. */
-    if (policy == EPHY_PREFS_RESTORE_SESSION_POLICY_NEVER)
-      session_delete (session);
-
     session_maybe_open_window (session, user_time);
   } else if (ephy_shell_get_n_windows (shell) == 0) {
     ephy_session_load (session, SESSION_STATE, user_time, cancellable,
